powered by
ensure() returns the dataframe (or tibble), reading it in if necessary
ensure(name)
Name of the dataframe
Stops in the case of an error
returns the (possibly retrieved) dataframe.
takes the name of the data and the suffix of the backing store for the dataframe and makes sure it is in our private environment.