Learn R Programming

us.census.geoheader (version 1.0.2)

uscgh.2010.decode: Return text describing the meaning of a value in a column

Description

uscgh.2010.decode() returns a textual description of a cell

Usage

uscgh.2010.decode(colname, colvalue = "", warnings = TRUE)

Arguments

colname

Name of the column to be described.

colvalue

Value whose description is wanted (\"""\" -- the default -- to describe, generically, `colname` itself).

warnings

Whether a `(colname,colvalue)` tuple that is not successfully decoded should produce a warning message. (In any event, the result will be NULL.)

Value

A character string describing the `colname` or `(colname,colvalue)` tuple, if found. If not found, `NULL` is returned (and, if `warnings` is `TRUE`, a warning is generated).

Details

takes as input the name of a column in the Geographic Header file from the 2010 US census, and a value found in that column, and attempts to return a description of the meaning of that value.

See Also

'RShowDoc("a-tour", package="us.census.geoheader")' for a short tour of a few columns of the database

Examples

Run this code
# NOT RUN {
uscgh.2010.decode('SUMLEV', 40)

# }

Run the code above in your browser using DataLab