Value whose description is wanted (\"""\" -- the
default -- to describe, generically, `colname` itself).
warnings
Whether a `(colname,colvalue)` tuple that is
not successfully decoded should produce a warning message. (In
any event, the result will be NULL.)
Value
A character string describing the `colname` or
`(colname,colvalue)` tuple, if found. If not found, `NULL` is
returned (and, if `warnings` is `TRUE`, a warning is generated).
Details
takes as input the name of a column in the Geographic Header file
from the 2010 US census, and a value found in that column, and
attempts to return a description of the meaning of that value.
See Also
'RShowDoc("a-tour", package="us.census.geoheader")' for a
short tour of a few columns of the database